@@ -13,7 +13,8 @@
 	# print(data.frame(cls = unlist(lapply(args, class)))) # save for debugging
 	
 	if (mode == 0L) {
-		specOK <-  ((class(args$spectra) == "Spectra") | (class(args$spectra) == "Spectra2D"))
+		specOK <- FALSE
+		specOK <-  any("Spectra" %in% class(args$spectra), "Spectra2D" %in% class(args$spectra))
 		if (!specOK) stop("Argument 'spectra' was not found or did not have class Spectra or Spectra2D")
 	}
 
@@ -30,14 +31,16 @@
 	if (mode == 12L) {
 		if (class(args$spectra) != "Spectra")
 			stop("Argument 'spectra' was not found or not a Spectra object")
-		pcaOK <- ((class(args$pca) == "prcomp") | (class(args$pca)[1] == "conPCA"))
+		pcaOK <- FALSE
+		pcaOK <- any("prcomp" %in% class(args$pca), "conPCA" %in% class(args$pca))
 		if (!pcaOK)  stop("Argument 'pca' was not found or did not have class prcomp or pcaCon")
 	}
 
 	if (mode == 22L) {
 		if (class(args$spectra) != "Spectra2D")
 			stop("Argument 'spectra' was not found or not a Spectra2D object")
-		pcaOK <- ((class(args$mia) == "mia") | (class(args$pfac) == "parafac"))
+		pcaOK <- FALSE
+		pcaOK <- any("mia" %in% class(args$mia), "parafac" %in% class(args$pfac))
 		if (!pcaOK)  stop("Argument 'mia/pfac' was not found or did not have class mia/parafac")
 	}
 
@@ -45,15 +48,18 @@
 
 	if (mode == 13L) { # Special for hcaScores.Spectra & plotScores.Spectra
 		if (class(args$spectra) != "Spectra")
-			stop("Argument 'spectra' was not found or not a Spectra2D object")
-		soOK <- ((class(args$so) == "prcomp") | (class(args$so)[1] == "conPCA"))
-		if (!soOK)  stop("Argument 'so' was not found or did not have class prcomp or pcaCon")
+			stop("Argument 'spectra' was not found or not a Spectra object")
+		soOK <- FALSE
+		soOK <- any("prcomp" %in% class(args$so), "conPCA" %in% class(args$so), 
+		  grepl("PCAgrid", args$so), "princomp" %in% class(args$so))
+		if (!soOK)  stop("Argument 'so' was not found or was not the correct class")
 	}
 
 	if (mode == 23L) { # Special for hcaScores.Spectra2D & plotScores.Spectra2D
 		if (class(args$spectra) != "Spectra2D")
 			stop("Argument 'spectra' was not found or not a Spectra2D object")
-		soOK <- ((class(args$so) == "mia") | (class(args$so) == "parafac"))
+		soOK <- FALSE
+		soOK <- any("mia" %in% class(args$so), "parafac" %in% class(args$so))
 		if (!soOK)  stop("Argument 'so' was not found or did not have class mia/parafac")
 	}
 } # end of chkArgs
