@@ -36,7 +36,7 @@
 		spectra$alt.sym <- spectra$alt.sym[-kill]
 	}
 	
-	if (class(spectra) == "Spectra2D") spectra$data <- spectra$data[-kill]
+	if (class(spectra) == "Spectra2D") spectra$data <- spectra$data[-kill, drop = FALSE]
 	
 	# Both classes
 	spectra$names <- spectra$names[-kill]
