@@ -4,8 +4,9 @@
 #' 
 sumGroups.Spectra <- function(spectra) {
 
-	# Prep either class
+	.chkArgs(mode = 11L)
 	chkSpectra(spectra)
+	
 	gr.l <- levels(spectra$group)
 	count <- length(gr.l)
 	
@@ -21,7 +22,6 @@ sumGroups.Spectra <- function(spectra) {
 			symbol = sym, alt.sym = asym))
 	}
 	
-	# Wrap up both classes
 	g.sum <- g.sum[-1,]
 	g.sum <- subset(g.sum, no. > 0) # drop groups with no members
 	rownames(g.sum) <- c(1:nrow(g.sum))
