@@ -3,29 +3,16 @@
 #' @noRd
 #' 
 sumSpectra.Spectra <- function(spectra, ...){
-		
+	
+	args2 <- as.list(match.call())[-1]
+	.chkArgs(mode = 11L)
 	chkSpectra(spectra)
 	
-	# Try to determine a sensible value for tol if none provided via the ...
-	
-	args <- names(as.list(match.call()[-1]))
+	# if (!("tol" %in% args2)) h <- check4Gaps(spectra$freq, silent = TRUE)
+	# if ("tol" %in% args2) h <- check4Gaps(spectra$freq, silent = TRUE, ...)	
 
-	if (!("tol" %in% args)) {
-		# Improvements to the automatic calc of a suitable tol value suggested
-		# by Dana Nadler in e-mails, early March 2017.  Any errors are mine however!		
-		# fdiff includes normal data resolution & any larger gaps
-		# hist(fdiff) should be dominated by data resolution
-		# unique(fdiff) shows that even basic data resolution suffers from encoding differences
-		fdiff <- diff(spectra$freq) 
-		tol <- abs(median(fdiff)) * 1.2 # ensures value is a bit larger than nominal resolution
-		h <- .check4Gaps(spectra$freq, tol = tol)	
-		}
-	
-
-	if ("tol" %in% args) h <- .check4Gaps(spectra$freq, ...)	
-
-	# Other summaries
-	
+	# Summarize a few things
+	h <- check4Gaps(spectra$freq, silent = TRUE)
 	g <- sumGroups(spectra)
 	res <- abs(median(diff(spectra$freq))) # consistent with method of determining tol above
 	
@@ -45,7 +32,7 @@ sumSpectra.Spectra <- function(spectra, ...){
 		
 	cat("\tThe frequency resolution is\n\t", res, " ", spectra$unit[1], "/point.\n\n", sep = "")
 	
-	if (length(h) > 1) {
+	if (nrow(h) > 1) {
 		cat("\tThis data set is not continuous\n\talong the frequency axis.\n")
 		cat("\tHere are the data chunks:\n\n")
 		print(h)
@@ -59,6 +46,6 @@ sumSpectra.Spectra <- function(spectra, ...){
 	cat("\n")
 	jnk <- .extraData(spectra)
 	
-	cat("\n*** Note: this data is an S3 object of class 'Spectra2D'\n")
+	cat("\n*** Note: this is an S3 object\nof class 'Spectra'\n")
 	}
 
